Index: wp-includes/theme.php
===================================================================
--- wp-includes/theme.php	(revision 17369)
+++ wp-includes/theme.php	(working copy)
@@ -171,9 +171,9 @@
  *
  * The style.css file must contain theme name, theme URI, and description. The
  * data can also contain author URI, author, template (parent template),
  * version, status, and finally tags. Some of these are not used by WordPress
  * administration panels, but are used by theme directory web sites which list
  * the theme.
  *
  * @since 1.5.0
  *
@@ -189,6 +189,7 @@
 		'AuthorURI' => 'Author URI',
 		'Version' => 'Version',
 		'Template' => 'Template',
+		'Template_Version' => 'Template Version',
 		'Status' => 'Status',
 		'Tags' => 'Tags'
 		);
@@ -219,6 +220,12 @@
 	$theme_data['AuthorURI'] = esc_url( $theme_data['AuthorURI'] );
 
 	$theme_data['Template'] = wp_kses( $theme_data['Template'], $themes_allowed_tags );
+	
+	$theme_data['Template_Version'] = wp_kses( $theme_data['Template_Version'], $themes_allowed_tags );
+	
+	// if there is no template being used then there should not be a value for the template version.
+	if ( $theme_data['Template'] == '' )
+		$theme_data['Template_Version'] = '';
 
 	$theme_data['Version'] = wp_kses( $theme_data['Version'], $themes_allowed_tags );
 
@@ -291,6 +298,7 @@
 		$version     = $theme_data['Version'];
 		$author      = $theme_data['Author'];
 		$template    = $theme_data['Template'];
+		$template_version    = $theme_data['Template_Version'];
 		$stylesheet  = dirname($theme_file);
 
 		$screenshot = false;
@@ -307,6 +315,7 @@
 		}
 
 		$parent_template = $template;
+		$parent_template_version = $template_version;
 
 		if ( empty($template) ) {
 			if ( file_exists("$theme_root/$stylesheet/index.php") )
@@ -425,6 +434,7 @@
 			'Author URI' => $theme_data['AuthorURI'],
 			'Version' => $version,
 			'Template' => $template,
+			'Template Version' => $template_version,
 			'Stylesheet' => $stylesheet,
 			'Template Files' => $template_files,
 			'Stylesheet Files' => $stylesheet_files,
@@ -171,9 +171,9 @@
  * The style.css file must contain theme name, theme URI, and description. The
  * data can also contain author URI, author, template (parent template),
- * version, status, and finally tags. Some of these are not used by WordPress
- * administration panels, but are used by theme directory web sites which list
- * the theme.
+ * template version (parent template version), version, status, and finally
+ * tags. Some of these are not used by WordPress administration panels, but are
+ * used by theme directory web sites which list the theme.
  *
  * @since 1.5.0
